Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(609)

Unified Diff: chrome/browser/renderer_host/render_view_host.h

Issue 251103: Move MediaPlayerAction to WebMediaPlayerAction. Switch to an enum and a... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/renderer_host/render_view_host.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/renderer_host/render_view_host.h
===================================================================
--- chrome/browser/renderer_host/render_view_host.h (revision 28235)
+++ chrome/browser/renderer_host/render_view_host.h (working copy)
@@ -47,6 +47,10 @@
struct WebApplicationInfo;
}
+namespace WebKit {
+struct WebMediaPlayerAction;
+}
+
//
// RenderViewHost
//
@@ -299,8 +303,9 @@
void ModalHTMLDialogClosed(IPC::Message* reply_msg,
const std::string& json_retval);
- // Send an action to the media player element located at |x|, |y|.
- void MediaPlayerActionAt(int x, int y, const MediaPlayerAction& action);
+ // Send an action to the media player element located at |location|.
+ void MediaPlayerActionAt(const gfx::Point& location,
+ const WebKit::WebMediaPlayerAction& action);
// Copies the image at the specified point.
void CopyImageAt(int x, int y);
« no previous file with comments | « no previous file | chrome/browser/renderer_host/render_view_host.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698